# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ColorTransfer(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    BT709 = "BT709"
    GAMMA22 = "GAMMA22"
    GAMMA28 = "GAMMA28"
    SMPTE170M = "SMPTE170M"
    SMPTE240M = "SMPTE240M"
    LINEAR = "LINEAR"
    LOG = "LOG"
    LOG_SQRT = "LOG_SQRT"
    IEC61966_2_4 = "IEC61966_2_4"
    BT1361_ECG = "BT1361_ECG"
    IEC61966_2_1 = "IEC61966_2_1"
    BT2020_10 = "BT2020_10"
    BT2020_12 = "BT2020_12"
    SMPTE2084 = "SMPTE2084"
    SMPTE428 = "SMPTE428"
    ARIB_STD_B67 = "ARIB_STD_B67"
